STS2 Adafruit TFT ok

Dependencies:   SPI_STMPE610 SPI_TFT_ILI9341 TFT_fonts mbed

Fork of TS_Eyes by Motoo Tanaka

Revision:
1:7cc0446656ae
Parent:
0:0b7a110bfceb
Child:
2:344ee4288dd7
--- a/main.cpp	Sat Dec 06 05:35:02 2014 +0000
+++ b/main.cpp	Sat Dec 06 09:54:42 2014 +0000
@@ -1,4 +1,4 @@
 /** TS_Eye TSI sample program using Adafruit 2.8" TFT with Touch
  *
  * @note Just like the good old X11 eyes
  * @note this program stares at the point where
@@ -52,7 +52,7 @@
     TFT.cls();
 }
 
-void moveEye(void)
+void moveEyes(void)
 {
     int dx, px ;
     float delta = 0.0 ;
@@ -69,7 +69,7 @@
     TFT.set_font((unsigned char*) Arial12x12);
     TFT.foreground(Blue) ;
     TFT.locate(60, 10) ;
-    TFT.printf("<< TS Eye >>") ;
+    TFT.printf("<< TS Eyes >>") ;
     TFT.locate(30, 280) ;
     TFT.printf("Use FRDM touch slider") ;
     TFT.locate(30, 300) ;
@@ -115,7 +115,7 @@
     for(;;) {
 
         if (awake) {
-            moveEye() ;
+            moveEyes() ;
             awake = false ;
         }
@@ -1,4 +1,4 @@
-/** TS_Eye TSI sample program using Adafruit 2.8" TFT with Touch
+/** TS_Eyes TSI sample program using Adafruit 2.8" TFT with Touch
  *
  * @note Just like the good old X11 eyes